@@ -1,4 +1,4 @@
-#Copyright (c) 2006 Erich Schubert erich@debian.org
+#Copyright (c) 2007 Erich Schubert erich@debian.org
 
 #Permission is hereby granted, free of charge, to any person obtaining a copy
 #of this software and associated documentation files (the "Software"), to deal
@@ -20,7 +20,9 @@
 import sys, socket, signal, re
 from util import Util
 from iptables import Iptables
+#import iptables_parse
 from popen2 import popen3
+from exception import PyromanException
 
 class Firewall:
 	"""
@@ -42,7 +44,8 @@ class Firewall:
 	rules -- list of firewall rules
 	"""
 	hostname = socket.gethostname()
-	# Timeout when the firewall setup will be rolled back when no OK is received.
+	# Timeout when the firewall setup will be rolled back when
+	# no OK is received.
 	timeout = 0
 
 	# Target names for the "accept", "drop" and "reject" commands
@@ -57,15 +60,18 @@ class Firewall:
 	nats = []
 	rules = []
 
+	# forwarding firewall. Default to yes
+	forwarding = True
+
 	# for testing kernel version
 	kernelversioncmd = "/bin/uname -r"
 	_kernelversion = None
 
 	def __init__(self):
 		"""
-		Dummy initialization function, will raise an exception!
+		Dummy initialization function, will raise PyromanException(an exception!)
 		"""
-		raise "Instanciation not supported!"
+		raise PyromanException("Instanciation not supported!")
 
 	class Error(Exception):
 		"""
@@ -179,7 +185,7 @@ class Firewall:
 			print line[0]
 	print_rules = staticmethod(print_rules)
 
-	def execute_rules():
+	def execute_rules(terse_mode=False):
 		"""
 		Execute the generated rules, rollback on error.
 		If Firewall.timeout is set, give the user some time to accept the
@@ -196,14 +202,28 @@ class Firewall:
 		lines = Firewall.calciptableslines()
 
 		# Save old firewall.
-		sys.stderr.write("Saving old firewall...\n")
+		if terse_mode:
+			sys.stderr.write("backing up current... ")
+		else:
+			sys.stderr.write("Backing up current firewall...\n")
 		savedlines = Iptables.save()
 
+		# parse the firewall setup
+		#try:
+		#	parsed = iptables_parse.parse(savedlines)
+		#except:
+		#	pass
+
 		# now try to execute the new rules
 		successful = False
 		try:
+			if terse_mode:
+				sys.stderr.write("activating new... ")
 			successful = Iptables.commit(lines)
-			sys.stderr.write("New firewall commited successfully.\n")
+			if terse_mode:
+				sys.stderr.write("success.\n")
+			else:
+				sys.stderr.write("New firewall commited successfully.\n")
 			if Firewall.timeout > 0:
 				sys.stderr.write("To accept the new configuration, type 'OK' within %d seconds!\n" % Firewall.timeout)
 				# setup timeout
@@ -218,20 +238,29 @@ class Firewall:
 				if not re.search("^(OK|YES)", input, re.I):
 					raise Firewall.Error("Success not confirmed by user")
 		except Iptables.Error, e:
-			sys.stderr.write("*"*70+"\n")
-			sys.stderr.write("An error occurred. Starting firewall restoration.\n")
+			if terse_mode:
+				sys.stderr.write("error... restoring backup.\n")
+			else:
+				sys.stderr.write("*"*70+"\n")
+				sys.stderr.write("An Iptables error occurred. Starting firewall restoration.\n")
 			Firewall.rollback(savedlines)
 			# show exception
 			sys.stderr.write("%s\n" % e);
 		except Firewall.Error, e:
-			sys.stderr.write("*"*70+"\n")
-			sys.stderr.write("An error occurred. Starting firewall restoration.\n")
+			if terse_mode:
+				sys.stderr.write("error. Restoring old firewall.\n")
+			else:
+				sys.stderr.write("*"*70+"\n")
+				sys.stderr.write("A Firewall error occurred. Starting firewall restoration.\n")
 			Firewall.rollback(savedlines)
 			# show exception
 			sys.stderr.write("%s\n" % e);
 		except:
-			sys.stderr.write("*"*70+"\n")
-			sys.stderr.write("An error occurred. Starting firewall restoration.\n")
+			if terse_mode:
+				sys.stderr.write("error. Restoring old firewall.\n")
+			else:
+				sys.stderr.write("*"*70+"\n")
+				sys.stderr.write("An unknown error occurred. Starting firewall restoration.\n")
 			Firewall.rollback(savedlines)
 			sys.stderr.write("\nHere is the exception triggered during execution:\n")
 			raise
@@ -252,7 +281,7 @@ class Firewall:
 			ir.close()
 			ie.close()
 			Firewall._kernelversion = result[0].strip()
-			# still no version number? - raise an exception
+			# still no version number? - raise PyromanException(an exception)
 			if not Firewall._kernelversion:
 				raise Error("Couldn't get kernel version!")
 		if not min and not max:
